crane-ec2
=========

.. image:: https://secure.travis-ci.org/timeredbull/crane-ec2.png
   :target: http://travis-ci.org/timeredbull/crane-ec2

crane-ec2 is part of `tsuru PaaS <http://github.com/timeredbull/tsuru>`_.

It is built to help service deployers to develop it's service api.


More docs coming.
